@@ -11,8 +11,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/jarcoal/httpmock"
-
 	"github.com/dnaeon/go-vcr/cassette"
 	"github.com/dnaeon/go-vcr/recorder"
 	"github.com/linode/linodego"
@@ -21,6 +19,8 @@ import (
 )
 
 var (
+	optInTestPrefixes []string
+
 	testingMode     = recorder.ModeDisabled
 	debugAPI        = false
 	validTestAPIKey = "NOTANAPIKEY"
@@ -154,24 +154,6 @@ func createTestClient(t *testing.T, fixturesYaml string) (*linodego.Client, func
 	return &c, recordStopper
 }
 
-func createMockClient(t *testing.T) *linodego.Client {
-	tokenSource := oauth2.StaticTokenSource(&oauth2.Token{AccessToken: validTestAPIKey})
-
-	client := &http.Client{
-		Transport: &oauth2.Transport{
-			Source: tokenSource,
-		},
-	}
-	httpmock.ActivateNonDefault(client)
-
-	t.Cleanup(func() {
-		httpmock.DeactivateAndReset()
-	})
-
-	c := linodego.NewClient(client)
-	return &c
-}
-
 // transportRecordWrapper returns a tranport.WrapperFunc which provides the test
 // recorder as an http.RoundTripper.
 func transportRecorderWrapper(t *testing.T, fixtureYaml string) (transport.WrapperFunc, func()) {
